@@ -312,8 +312,9 @@ class Extend_Pdf:
                     meta['dc:description'] = 'Put the Abstract here'
 
         Args:
-            set_pikepdf_as_editor: Update the metadata to show that this
-                version of pikepdf is the most recent software to modify the metadata.
+            set_pikepdf_as_editor: Automatically update the metadata ``pdf:Producer``
+                to show that this version of pikepdf is the most recent software to
+                modify the metadata, and ``xmp:MetadataDate`` to timestamp the update.
                 Recommended, except for testing.
 
             update_docinfo: Update the standard fields of DocumentInfo
@@ -625,7 +626,7 @@ class Extend_Pdf:
         Save all modifications to this :class:`pikepdf.Pdf`.
 
         Args:
-            filename: Where to write the output. If a file
+            filename_or_stream: Where to write the output. If a file
                 exists in this location it will be overwritten.
                 If the file was opened with ``allow_overwriting_input=True``,
                 then it is permitted to overwrite the original file, and
@@ -705,6 +706,10 @@ class Extend_Pdf:
                 Alternately, an ``Encryption`` object may be provided that
                 sets the parameters for new encryption.
 
+        Raises:
+            PdfError
+            ForeignObjectError
+
         You may call ``.save()`` multiple times with different parameters
         to generate different versions of a file, and you *may* continue
         to modify the file after saving it. ``.save()`` does not modify
